/*
 */
/** ============================================================================
*  @file       pinmux_xwr6843AOP.h
*
*  @brief      PINMUX pad settings for 6843AOP device
*
*  ============================================================================
*/

#ifndef ti_drivers_PINMUX_xwr68xx__include
#define ti_drivers_PINMUX_xwr68xx__include
    
#ifdef __cplusplus
    extern "C" {
#endif




/** @addtogroup PINMUX_DRIVER_PAD_FUNCTIONS_6843AOP
 *
 * @brief
 *  PAD Functionality
 *
 @{ */

/** @name PINB2_PADAA
*  PINB2_PADAA functionality
*/
/**@{*/
#define SOC_XWR6843AOP_PINB2_PADAA                     0U
#define SOC_XWR6843AOP_PINB2_PADAA_GPIO_12             0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINB2_PADAA_SPI_HOST_INTR       1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINB2_PADAA_SPIB_CSN1           6U    /*< SPI Channel B Chip Select*/
/**@}*/ /*PINB2_PADAA*/

/** @name PINM2_PADAB 
*   PINM2_PADAB functionality
*/
/**@{*/
#define SOC_XWR6843AOP_PINM2_PADAB                     1U
#define SOC_XWR6843AOP_PINM2_PADAB_GPIO_13             0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINM2_PADAB_GPIO_0              1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINM2_PADAB_PMIC_CLKOUT         2U    /*< Output Clock from XWR68xx device for PMIC*/
#define SOC_XWR6843AOP_PINM2_PADAB_EPWM1_B             10U    /*< PWM Module 1 - OutPut B*/
#define SOC_XWR6843AOP_PINM2_PADAB_EPWM2_A             11U    /*< PWM Module 2 - OutPut A*/
/**@}*/ /*PINM2_PADAB*/

/** @name PINL3_PADAC
 *  PINL3_PADAC functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINL3_PADAC                     2U
#define SOC_XWR6843AOP_PINL3_PADAC_GPIO_16             0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINL3_PADAC_GPIO_1              1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINL3_PADAC_SYNC_OUT            2U    /*< Low Frequency Synchronization Signal output*/
#define SOC_XWR6843AOP_PINL3_PADAC_DMM_MUXIN           12U    /*< Debug Interface (Hardware In Loop) Mux Select between 
                                                              DMM1 and DMM2 (Two Instances)*/
#define SOC_XWR6843AOP_PINL3_PADAC_SPIB_CSN1           13U    /*< SPI Channel B Chip Select (Instance ID 1)*/
#define SOC_XWR6843AOP_PINL3_PADAC_SPIB_CSN2           14U    /*< SPI Channel B Chip Select (Instance ID 2)*/
#define SOC_XWR6843AOP_PINL3_PADAC_EPWM1_SYNCI         15U    /*< PWM Module 1 - Input Synchronization Signal*/
/**@}*/ /*PINL3_PADAC*/

/** @name PINF2_PADAD
 *  PINF2_PADAD functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINF2_PADAD                     3U
#define SOC_XWR6843AOP_PINF2_PADAD_GPIO_19             0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINF2_PADAD_SPIA_MOSI           1U    /*< SPI Channel A - Master Out Slave In*/
#define SOC_XWR6843AOP_PINF2_PADAD_CANFD_RX            2U    /*< CAN FD (MCAN) Receive Signal*/
#define SOC_XWR6843AOP_PINF2_PADAD_DSS_UART_TX         8U    /*< Debug UART Transmit [DSP]*/
/**@}*/ /*PINF2_PADAD*/

/** @name PIND1_PADAE
 *  PIND1_PADAE functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PIND1_PADAE                     4U
#define SOC_XWR6843AOP_PIND1_PADAE_GPIO_20             0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PIND1_PADAE_SPIA_MISO           1U    /*< SPI Channel A - Master In Slave Out*/
#define SOC_XWR6843AOP_PIND1_PADAE_CANFD_TX            2U    /*< CAN FD (MCAN) Transmit Signal*/
/**@}*/ /*PIND1_PADAE*/

/** @name PIND2_PADAF
 *  PIND2_PADAF functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PIND2_PADAF                     5U
#define SOC_XWR6843AOP_PIND2_PADAF_GPIO_3              0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PIND2_PADAF_SPIA_CLK            1U    /*< SPI Channel A - Clock*/
#define SOC_XWR6843AOP_PIND2_PADAF_CANFD2_RX           6U    /*< CANFD2 (MCANB) Receive Signal*/
#define SOC_XWR6843AOP_PIND2_PADAF_DSS_UART_TX         7U    /*< Debug UART Transmit [DSP]*/
/**@}*/ /*PIND2_PADAF*/

/** @name PINC2_PADAG
 *  PINC2_PADAG functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINC2_PADAG                     6U
#define SOC_XWR6843AOP_PINC2_PADAG_GPIO_30             0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINC2_PADAG_SPIA_CSN            1U    /*< SPI Channel A - Chip Select*/
#define SOC_XWR6843AOP_PINC2_PADAG_CANFD2_TX           6U    /*< CANFD2 (MCANB) Transmit Signal*/
/**@}*/ /*PINC2_PADAG*/

/** @name PING1_PADAH
 *  PING1_PADAH functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PING1_PADAH                     7U
#define SOC_XWR6843AOP_PING1_PADAH_GPIO_21             0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PING1_PADAH_SPIB_MOSI           1U    /*< SPI Channel B - Master Out Slave In*/
#define SOC_XWR6843AOP_PING1_PADAH_I2C_SDA             2U    /*< I2C Data */
/**@}*/ /*PING1_PADAH*/

/** @name PING3_PADAI
 *  PING3_PADAI functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PING3_PADAI                     8U
#define SOC_XWR6843AOP_PING3_PADAI_GPIO_22             0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PING3_PADAI_SPIB_MISO           1U    /*< SPI Channel B - Master In Slave Out*/
#define SOC_XWR6843AOP_PING3_PADAI_I2C_SCL             2U    /*< I2C Clock*/
#define SOC_XWR6843AOP_PING3_PADAI_DSS_UART_TX         6U    /*< Debug UART Transmit [DSP]*/
/**@}*/ /*PING3_PADAI*/

/** @name PINE2_PADAJ
 *  PINE2_PADAJ functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINE2_PADAJ                     9U
#define SOC_XWR6843AOP_PINE2_PADAJ_GPIO_5              0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINE2_PADAJ_SPIB_CLK            1U    /*< SPI Channel B - Clock*/
#define SOC_XWR6843AOP_PINE2_PADAJ_MSS_UARTA_RX        2U    /*< Master Subsystem  - UART A Receive*/
#define SOC_XWR6843AOP_PINE2_PADAJ_MSS_UARTB_TX        6U    /*< Master Subsystem  - UART B Transmit*/
#define SOC_XWR6843AOP_PINE2_PADAJ_BSS_UART_TX         7U    /*< Debug UART Transmit [Radar Block]*/
#define SOC_XWR6843AOP_PINE2_PADAJ_CANFD_RX            8U    /*< CAN FD (MCAN) Receive Signal*/
/**@}*/ /*PINE2_PADAJ*/

/** @name PIND3_PADAK
 *  PIND3_PADAK functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PIND3_PADAK                     10U
#define SOC_XWR6843AOP_PIND3_PADAK_GPIO_4              0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PIND3_PADAK_SPIB_CSN            1U    /*< SPI Channel B Chip Select (Instance ID 0)*/
#define SOC_XWR6843AOP_PIND3_PADAK_MSS_UARTA_TX        2U    /*< Master Subsystem  - UART A Transmit*/
#define SOC_XWR6843AOP_PIND3_PADAK_MSS_UARTB_TX        6U    /*< Master Subsystem  - UART B Transmit*/
#define SOC_XWR6843AOP_PIND3_PADAK_BSS_UART_TX         7U    /*< Debug UART Transmit [Radar Block]*/
#define SOC_XWR6843AOP_PIND3_PADAK_QSPI_CLKEXT         8U    /*< QSPI Clock (Used with Serial Data Flash)*/
#define SOC_XWR6843AOP_PIND3_PADAK_CANFD_TX            9U    /*< CAN FD (MCAN) Transmit Signal*/
/**@}*/ /*PIND3_PADAK*/

/** @name PINH3_PADAL
 *  PINH3_PADAL functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINH3_PADAL                     11U
#define SOC_XWR6843AOP_PINH3_PADAL_GPIO_8              0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINH3_PADAL_QSPI_D0              1U    /*< QSPI Data Line #0 (Used with Serial Data Flash)*/
#define SOC_XWR6843AOP_PINH3_PADAL_SPIB_MISO           2U    /*< SPI Channel B - Master In Slave Out*/
/**@}*/ /*PINH3_PADAL*/

/** @name PING2_PADAM
 *  PING2_PADAM functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PING2_PADAM                     12U
#define SOC_XWR6843AOP_PING2_PADAM_GPIO_9              0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PING2_PADAM_QSPI_D1              1U    /*< QSPI Data Line #1 (Used with Serial Data Flash)*/
#define SOC_XWR6843AOP_PING2_PADAM_SPIB_MOSI           2U    /*< SPI Channel B - Master Out Slave In*/
#define SOC_XWR6843AOP_PING2_PADAM_SPIB_CSN2           8U    /*< SPI Channel B Chip Select (Instance ID 2)*/
/**@}*/ /*PING2_PADAM*/

/** @name PINJ3_PADAN
 *  PINJ3_PADAN functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINJ3_PADAN                     13U
#define SOC_XWR6843AOP_PINJ3_PADAN_GPIO_10             0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINJ3_PADAN_QSPI_D2              1U    /*< QSPI Data Line #2 (Used with Serial Data Flash)*/
#define SOC_XWR6843AOP_PINJ3_PADAN_CANFD_TX            8U    /*< CAN FD (MCAN) Transmit Signal*/
/**@}*/ /*PINJ3_PADAN*/

/** @name PINK2_PADAO
 *  PINK2_PADAO functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINK2_PADAO                     14U
#define SOC_XWR6843AOP_PINK2_PADAO_GPIO_11             0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINK2_PADAO_QSPI_D3              1U    /*< QSPI Data Line #3 (Used with Serial Data Flash)*/
#define SOC_XWR6843AOP_PINK2_PADAO_CANFD_RX            8U    /*< CAN FD (MCAN) Receive Signal*/
/**@}*/ /*PINK2_PADAO*/

/** @name PINH2_PADAP
 *  PINH2_PADAP functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINH2_PADAP                     15U
#define SOC_XWR6843AOP_PINH2_PADAP_GPIO_7              0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINH2_PADAP_QSPI_CLK            1U    /*< QSPI Clock (Used with Serial Data Flash)*/
#define SOC_XWR6843AOP_PINH2_PADAP_SPIB_CLK            2U    /*< SPI Channel B - Clock*/
#define SOC_XWR6843AOP_PINH2_PADAP_DSS_UART_TX         6U    /*< Debug UART Transmit [DSP]*/
/**@}*/ /*PINH2_PADAP*/

/** @name PINJ2_PADAQ
 *  PINJ2_PADAQ functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINJ2_PADAQ                     16U
#define SOC_XWR6843AOP_PINJ2_PADAQ_GPIO_6              0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINJ2_PADAQ_QSPI_CSN            1U    /*< QSPI Chip Select (Used with Serial Data Flash)*/
#define SOC_XWR6843AOP_PINJ2_PADAQ_SPIB_CSN            2U    /*< SPI Channel B Chip Select (Instance ID 0)*/
/**@}*/ /*PINJ2_PADAQ*/

/** @name PINU14_PADAR 
 *  PINU14_PADAR  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINU14_PADAR                      17U
#define SOC_XWR6843AOP_PINU14_PADAR_NERROR_IN            0U    /*< Failsafe input to the device. Nerror output from any other device 
                                                                can be concentrated in the error signaling monitor module inside the 
                                                                device and appropriate action can be taken by Firmware*/
/**@}*/ /*PINU14_PADAR_*/

/** @name PINU13_PADAS 
 *  PINU13_PADAS  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINU13_PADAS                      18U
#define SOC_XWR6843AOP_PINU13_PADAS_WARM_RESET           0U    /*< Open drain fail safe warm reset signal. Can be driven from PMIC for 
                                                                diagnostic or can be used as status signal that the device is going 
                                                                through reset.*/
/**@}*/ /*PINU13_PADAS_*/

/** @name PINU15_PADAT 
 *  PINU15_PADAT  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINU15_PADAT                      19U
#define SOC_XWR6843AOP_PINU15_PADAT_NERROR_OUT           0U    /*< Open drain fail safe output signal. Connected to PMIC/Processor/MCU 
                                                              to indicate that some severe criticality fault has happened. Recovery 
                                                              would be through reset.*/
/**@}*/ /*PINU15_PADAT_*/

/** @name PINT3_PADAU
 *  PINT3_PADAU functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINT3_PADAU                     20U
#define SOC_XWR6843AOP_PINT3_PADAU_GPIO_17             0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINT3_PADAU_TCK                 1U    /*< JTAG Test Clock*/
#define SOC_XWR6843AOP_PINT3_PADAU_MSS_UARTB_TX        2U    /*< Master Subsystem  - UART B Transmit*/
#define SOC_XWR6843AOP_PINT3_PADAU_CANFD_TX            8U    /*< CAN FD (MCAN) Transmit Signal*/
/**@}*/ /*PINT3_PADAU*/

/** @name PINU8_PADAV
 *  PINU8_PADAV functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINU8_PADAV                     21U
#define SOC_XWR6843AOP_PINU8_PADAV_GPIO_18             0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINU8_PADAV_TMS                 1U    /*< JTAG Test Mode Signal*/
#define SOC_XWR6843AOP_PINU8_PADAV_BSS_UART_TX         2U    /*< Debug UART Transmit [Radar Block]*/
#define SOC_XWR6843AOP_PINU8_PADAV_CANFD_RX            6U    /*< CAN FD (MCAN) Receive Signal*/
/**@}*/ /*PINU8_PADAV*/

/** @name PINU9_PADAW
 *  PINU9_PADAW functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINU9_PADAW                     22U
#define SOC_XWR6843AOP_PINU9_PADAW_GPIO_23             0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINU9_PADAW_TDI                 1U    /*< JTAG Test Data Input */
#define SOC_XWR6843AOP_PINU9_PADAW_MSS_UARTA_RX        2U    /*< Master Subsystem  - UART A Receive*/
/**@}*/ //Subsystem  -

/** @name PINU10_PADAX
 *  PINU10_PADAX functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINU10_PADAX                     23U
#define SOC_XWR6843AOP_PINU10_PADAX_GPIO_24             0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINU10_PADAX_TDO                 1U    /*< JTAG Test Data Output*/
#define SOC_XWR6843AOP_PINU10_PADAX_MSS_UARTA_TX        2U    /*< Master Subsystem  - UART A Transmit*/
#define SOC_XWR6843AOP_PINU10_PADAX_MSS_UARTB_TX        6U    /*< Master Subsystem  - UART B Transmit*/
#define SOC_XWR6843AOP_PINU10_PADAX_BSS_UART_TX         7U    /*< Debug UART Transmit [Radar Block]*/
#define SOC_XWR6843AOP_PINU10_PADAX_NDMM_EN             9U    /*< Debug Interface (Hardware In Loop) Enable - Active Low Signal*/
/**@}*/ /*PINU10_PADAX*/

/** @name PINV13_PADAY 
 *  PINV13_PADAY  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINV13_PADAY                      24U
#define SOC_XWR6843AOP_PINV13_PADAY_GPIO_25              0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINV13_PADAY_MCU_CLKOUT           1U    /*< Programmable clock given out to external MCU or the processor*/
#define SOC_XWR6843AOP_PINV13_PADAY_EPWM1_A              12U    /*< PWM Module 1 - OutPut A*/
/**@}*/ /*PINV13_PADAY_*/

/** @name PINK3_PADAZ
 *  PINK3_PADAZ functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINK3_PADAZ                     25U
#define SOC_XWR6843AOP_PINK3_PADAZ_GPIO_26             0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINK3_PADAZ_GPIO_2              1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINK3_PADAZ_OSC_CLKOUT          2U    /*< Reference clock output from clocking sub system after cleanup PLL*/
#define SOC_XWR6843AOP_PINK3_PADAZ_MSS_UARTB_TX        7U    /*< Master Subsystem  - UART B Transmit*/
#define SOC_XWR6843AOP_PINK3_PADAZ_BSS_UART_TX         8U    /*< Debug UART Transmit [Radar Block]*/
#define SOC_XWR6843AOP_PINK3_PADAZ_SYNC_OUT            9U    /*< Low Frequency Synchronization Signal output*/
#define SOC_XWR6843AOP_PINK3_PADAZ_PMIC_CLKOUT         10U    /*< Output Clock from XWR68xx device for PMIC*/
/**@}*/ /*PINK3_PADAZ*/

/** @name PINV10_PADBA 
 *  PINV10_PADBA  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINV10_PADBA                      26U
#define SOC_XWR6843AOP_PINV10_PADBA_GPIO_27              0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINV10_PADBA_PMIC_CLKOUT          1U    /*< Output Clock from XWR68xx device for PMIC*/
#define SOC_XWR6843AOP_PINV10_PADBA_EPWM1_B              11U    /*< PWM Module 1 - OutPut B*/
#define SOC_XWR6843AOP_PINV10_PADBA_EPWM2_A              12U    /*< PWM Module 2- OutPut A*/
/**@}*/ /*PINV10_PADBA_*/

/** @name PINU12_PADBB 
 *  PINU12_PADBB  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINU12_PADBB                      27U
#define SOC_XWR6843AOP_PINU12_PADBB_GPIO_28              0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINU12_PADBB_SYNC_IN              1U    /*< Low frequency Synchronization signal input */
#define SOC_XWR6843AOP_PINU12_PADBB_MSS_UARTB_RX         6U    /*< Master Subsystem  - UART B Receiver*/
#define SOC_XWR6843AOP_PINU12_PADBB_DMM_MUXIN            7U    /*< Debug Interface (Hardware In Loop) Mux Select between DMM1 and DMM2 (Two Instances)*/
#define SOC_XWR6843AOP_PINU12_PADBB_SYNC_OUT             9U    /*< Low Frequency Synchronization Signal output*/
/**@}*/ /*PINU12_PADBB_*/

/** @name PINM3_PADBC
 *  PINM3_PADBC functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINM3_PADBC                     28U
#define SOC_XWR6843AOP_PINM3_PADBC_GPIO_29             0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINM3_PADBC_SYNC_OUT            1U    /*< Low Frequency Synchronization Signal output*/
#define SOC_XWR6843AOP_PINM3_PADBC_DMM_MUXIN           9U    /*< Debug Interface (Hardware In Loop) Mux Select between DMM1 and DMM2 (Two Instances)*/
#define SOC_XWR6843AOP_PINM3_PADBC_SPIB_CSN1           10U    /*< SPI Channel B Chip Select (Instance ID 1)*/
#define SOC_XWR6843AOP_PINM3_PADBC_SPIB_CSN2           11U    /*< SPI Channel B Chip Select (Instance ID 2)*/
/**@}*/ /*PINM3_PADBC*/

/** @name PINV16_PADBD 
 *  PINV16_PADBD  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINV16_PADBD                      29U
#define SOC_XWR6843AOP_PINV16_PADBD_GPIO_15              0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINV16_PADBD_RS232_RX             1U    /*< Debug UART (Operates as Bus Master) - Receive Signal*/
#define SOC_XWR6843AOP_PINV16_PADBD_MSS_UARTA_RX         2U    /*< Master Subsystem  - UART A Receive*/
#define SOC_XWR6843AOP_PINV16_PADBD_BSS_UART_TX          6U    /*< Debug UART Transmit [Radar Block]*/
#define SOC_XWR6843AOP_PINV16_PADBD_MSS_UARTB_RX         7U    /*< Master Subsystem  - UART B Receive*/
#define SOC_XWR6843AOP_PINV16_PADBD_CANFD_RX             8U    /*< CAN FD (MCAN) Receive Signal*/
#define SOC_XWR6843AOP_PINV16_PADBD_I2C_SCL              9U    /*< I2C Clock*/
#define SOC_XWR6843AOP_PINV16_PADBD_EPWM2_A              10U    /*< PWM Module 2 - OutPut A*/
#define SOC_XWR6843AOP_PINV16_PADBD_EPWM2_B              11U    /*< PWM Module 2- OutPut B*/
#define SOC_XWR6843AOP_PINV16_PADBD_EPWM3_A              12U    /*< PWM Module 3 - OutPut A*/
/**@}*/ /*PINV16_PADBD_*/

/** @name PINU16_PADBE 
 *  PINU16_PADBE  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINU16_PADBE                      30U
#define SOC_XWR6843AOP_PINU16_PADBE_GPIO_14              0U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINU16_PADBE_RS232_TX             1U    /*< Debug UART (Operates as Bus Master) - Receive Signal*/
#define SOC_XWR6843AOP_PINU16_PADBE_MSS_UARTA_TX         5U    /*< Master Subsystem  - UART A Transmit*/
#define SOC_XWR6843AOP_PINU16_PADBE_MSS_UARTB_TX         6U    /*< Master Subsystem  - UART B Transmit*/
#define SOC_XWR6843AOP_PINU16_PADBE_BSS_UART_TX          7U    /*< Debug UART Transmit [Radar Block]*/
#define SOC_XWR6843AOP_PINU16_PADBE_CANFD_TX             10U    /*< CAN FD (MCAN) Transmit Signal*/
#define SOC_XWR6843AOP_PINU16_PADBE_I2C_SDA              11U    /*< I2C Data */
#define SOC_XWR6843AOP_PINU16_PADBE_EPWM1_A              12U    /*< PWM Module 1 - OutPut A*/
#define SOC_XWR6843AOP_PINU16_PADBE_EPWM1_B              13U    /*< PWM Module 1 - OutPut B*/
#define SOC_XWR6843AOP_PINU16_PADBE_NDMM_EN              14U    /*< Debug Interface (Hardware In Loop) Enable - Active Low Signal*/
#define SOC_XWR6843AOP_PINU16_PADBE_EPWM2_A              15U    /*< PWM Module 2 - OutPut A*/
/**@}*/ /*PINU16_PADBE_*/

/** @name PINU7_PADBF 
 *  PINU7_PADBF  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINU7_PADBF                      31U
#define SOC_XWR6843AOP_PINU7_PADBF_TRACE_DATA0         0U    /*< Debug Trace Output - Data Line*/
#define SOC_XWR6843AOP_PINU7_PADBF_GPIO_31              1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINU7_PADBF_DMM0                 2U    /*< Debug Interface (Hardware In Loop)  - Data Line*/
#define SOC_XWR6843AOP_PINU7_PADBF_MSS_UARTA_TX         4U    /*< Master Subsystem  - UART A Transmit*/
/**@}*/ /*PINU7_PADBF_*/

/** @name PINU6_PADBG 
 *  PINU6_PADBG  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINU6_PADBG                      32U
#define SOC_XWR6843AOP_PINU6_PADBG_TRACE_DATA1         0U    /*< Debug Trace Output - Data Line*/
#define SOC_XWR6843AOP_PINU6_PADBG_GPIO_32              1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINU6_PADBG_DMM1                 2U    /*< Debug Interface (Hardware In Loop)  - Data Line*/
/**@}*/ /*PINU6_PADBG_*/

/** @name PINV5_PADBH 
 *  PINV5_PADBH  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINV5_PADBH                      33U
#define SOC_XWR6843AOP_PINV5_PADBH_TRACE_DATA2         0U    /*< Debug Trace Output - Data Line*/
#define SOC_XWR6843AOP_PINV5_PADBH_GPIO_33              1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINV5_PADBH_DMM2                 2U    /*< Debug Interface (Hardware In Loop)  - Data Line*/
/**@}*/ /*PINV5_PADBH_*/

/** @name PINU5_PADBI 
 *  PINU5_PADBI  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINU5_PADBI                      34U
#define SOC_XWR6843AOP_PINU5_PADBI_TRACE_DATA3         0U    /*< Debug Trace Output - Data Line*/
#define SOC_XWR6843AOP_PINU5_PADBI_GPIO_34              1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINU5_PADBI_DMM3                 2U    /*< Debug Interface (Hardware In Loop)  - Data Line*/
#define SOC_XWR6843AOP_PINU5_PADBI_EPWM3_SYNCO          4U    /*< */
/**@}*/ /*PINU5_PADBI_*/

/** @name PINV3_PADBJ 
 *  PINV3_PADBJ  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINV3_PADBJ                      35U
#define SOC_XWR6843AOP_PINV3_PADBJ_TRACE_DATA4         0U    /*< Debug Trace Output - Data Line*/
#define SOC_XWR6843AOP_PINV3_PADBJ_GPIO_35              1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINV3_PADBJ_DMM4                 2U    /*< Debug Interface (Hardware In Loop)  - Data Line*/
#define SOC_XWR6843AOP_PINV3_PADBJ_EPWM2_SYNCO          4U    /*< */
/**@}*/ /*PINV3_PADBJ_*/

/** @name PINM1_PADBK 
 *  PINM1_PADBK  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINM1_PADBK                      36U
#define SOC_XWR6843AOP_PINM1_PADBK_TRACE_DATA5         0U    /*< Debug Trace Output - Data Line*/
#define SOC_XWR6843AOP_PINM1_PADBK_GPIO_36              1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINM1_PADBK_DMM5                 2U    /*< Debug Interface (Hardware In Loop)  - Data Line*/
#define SOC_XWR6843AOP_PINM1_PADBK_MSS_UARTB_TX         5U    /*< Master Subsystem  - UART B Transmit*/
/**@}*/ /*PINM1_PADBK_*/

/** @name PINL2_PADBL 
 *  PINL2_PADBL  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINL2_PADBL                      37U
#define SOC_XWR6843AOP_PINL2_PADBL_TRACE_DATA6         0U    /*< Debug Trace Output - Data Line*/
#define SOC_XWR6843AOP_PINL2_PADBL_GPIO_37              1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINL2_PADBL_DMM6                 2U    /*< Debug Interface (Hardware In Loop)  - Data Line*/
#define SOC_XWR6843AOP_PINL2_PADBL_BSS_UART_TX          5U    /*< Debug UART Transmit [Radar Block]*/
/**@}*/ /*PINL2_PADBL_*/

/** @name PINL1_PADBM 
 *  PINL1_PADBM  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINL1_PADBM                      38U
#define SOC_XWR6843AOP_PINL1_PADBM_TRACE_DATA7         0U    /*< Debug Trace Output - Data Line*/
#define SOC_XWR6843AOP_PINL1_PADBM_GPIO_38              1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINL1_PADBM_DMM7                 2U    /*< Debug Interface (Hardware In Loop)  - Data Line*/
#define SOC_XWR6843AOP_PINL1_PADBM_DSS_UART_TX          5U    /*< Debug UART Transmit [DSP]*/
/**@}*/ /*PINL1_PADBM_*/

/** @name PINC3_PADBN 
 *  PINC3_PADBN  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINC3_PADBN                      39U
#define SOC_XWR6843AOP_PINC3_PADBN_TRACE_DATA8          0U    /*< Debug Trace Output - Data Line*/
#define SOC_XWR6843AOP_PINC3_PADBN_GPIO_39              1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINC3_PADBN_DMM8                 2U    /*< Debug Interface (Hardware In Loop)  - Data Line*/
#define SOC_XWR6843AOP_PINC3_PADBN_CANFD_TX            4U    /*<*/
#define SOC_XWR6843AOP_PINC3_PADBN_EPWM1SYNCI           5U    /*<*/
/**@}*/ /*PINC3_PADBN_*/

/** @name PINB3_PADBO 
 *  PINB3_PADBO  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINB3_PADBO                      40U
#define SOC_XWR6843AOP_PINB3_PADBO_TRACE_DATA9          0U    /*< Debug Trace Output - Data Line*/
#define SOC_XWR6843AOP_PINB3_PADBO_GPIO_40              1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINB3_PADBO_DMM9                 2U    /*< Debug Interface (Hardware In Loop)  - Data Line*/
#define SOC_XWR6843AOP_PINB3_PADBO_CANFD_RX            4U    /*< */
#define SOC_XWR6843AOP_PINB3_PADBO_EPWM1SYNCO           5U    /*<*/
/**@}*/ /*PINB3_PADBO_*/

/** @name PINC4_PADBP 
 *  PINC4_PADBP  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINC4_PADBP                      41U
#define SOC_XWR6843AOP_PINC4_PADBP_TRACE_DATA10         0U    /*< Debug Trace Output - Data Line*/
#define SOC_XWR6843AOP_PINC4_PADBP_GPIO_41              1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINC4_PADBP_DMM10                2U    /*< Debug Interface (Hardware In Loop)  - Data Line*/
#define SOC_XWR6843AOP_PINC4_PADBP_EPWM3_A               4U    /*< */
/**@}*/ /*PINC4_PADBP_*/

/** @name PINA3_PADBQ 
 *  PINA3_PADBQ  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINA3_PADBQ                      42U
#define SOC_XWR6843AOP_PINA3_PADBQ_TRACE_DATA11         0U    /*< Debug Trace Output - Data Line*/
#define SOC_XWR6843AOP_PINA3_PADBQ_GPIO_42              1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINA3_PADBQ_DMM11                2U    /*< Debug Interface (Hardware In Loop)  - Data Line*/
#define SOC_XWR6843AOP_PINA3_PADBQ_EPWM3_B               4U    /*< */
/**@}*/ /*PINA3_PADBQ*/

/** @name PINB4_PADBR 
 *  PINB4_PADBR  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINB4_PADBR                      43U
#define SOC_XWR6843AOP_PINB4_PADBR_TRACE_DATA12         0U    /*< Debug Trace Output - Data Line*/
#define SOC_XWR6843AOP_PINB4_PADBR_GPIO_43              1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINB4_PADBR_DMM12                2U    /*< Debug Interface (Hardware In Loop)  - Data Line*/
#define SOC_XWR6843AOP_PINB4_PADBR_EPWM1_A               4U    /*< */
#define SOC_XWR6843AOP_PINB4_PADBR_CANFD_TX            5U    /*< */
/**@}*/ /*PINB4_PADBR_*/

/** @name PINA4_PADBS 
 *  PINA4_PADBS  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINA4_PADBS                      44U
#define SOC_XWR6843AOP_PINA4_PADBS_TRACE_DATA13         0U    /*< Debug Trace Output - Data Line*/
#define SOC_XWR6843AOP_PINA4_PADBS_GPIO_44              1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINA4_PADBS_DMM13                2U    /*< Debug Interface (Hardware In Loop)  - Data Line*/
#define SOC_XWR6843AOP_PINA4_PADBS_EPWM1_B               4U    /*<*/
#define SOC_XWR6843AOP_PINA4_PADBS_CANFD_RX            5U    /*<*/
/**@}*/ /*PINA4_PADBS_*/

/** @name PINC5_PADBT 
 *  PINC5_PADBT  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINC5_PADBT                      45U
#define SOC_XWR6843AOP_PINC5_PADBT_TRACE_DATA14         0U    /*< Debug Trace Output - Data Line*/
#define SOC_XWR6843AOP_PINC5_PADBT_GPIO_45              1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINC5_PADBT_DMM14                2U    /*< Debug Interface (Hardware In Loop)  - Data Line*/
#define SOC_XWR6843AOP_PINC5_PADBT_EPWM2_A               4U    /*< */
/**@}*/ /*PINC5_PADBT_*/

/** @name PINB5_PADBU 
 *  PINB5_PADBU  functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINB5_PADBU                      46U
#define SOC_XWR6843AOP_PINB5_PADBU_TRACE_DATA15         0U    /*< Debug Trace Output - Data Line*/
#define SOC_XWR6843AOP_PINB5_PADBU_GPIO_46              1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINB5_PADBU_DMM15                2U    /*< Debug Interface (Hardware In Loop)  - Data Line*/
#define SOC_XWR6843AOP_PINB5_PADBU_EPWM2_B               4U    /*< */
/**@}*/ /*PINB5_PADBU_*/

/** @name PINU3_PADBV
 *  PINU3_PADBV functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINU3_PADBV                     47U
#define SOC_XWR6843AOP_PINU3_PADBV_TRACE_CLK           0U    /*< Debug Trace Output - Clock*/
#define SOC_XWR6843AOP_PINU3_PADBV_GPIO_47             1U    /*< General Purpose IO*/
#define SOC_XWR6843AOP_PINU3_PADBV_DMM_CLK             2U    /*< Debug Interface (Hardware In Loop)  - Clock*/
/**@}*/ /*PINU3_PADBV*/

/** @name PINU4_PADBW
 *  PINU4_PADBW functionality
 */
/**@{*/
#define SOC_XWR6843AOP_PINU4_PADBW                     48U
#define SOC_XWR6843AOP_PINU4_PADBW_TRACE_CTL           0U    /*< Debug Trace Output - Control*/
#define SOC_XWR6843AOP_PINU4_PADBW_DMM_SYNC            2U    /*< Debug Interface (Hardware In Loop)  - Sync*/
/**@}*/ /*PINU4_PADBW*/



/** @}*/

#define PINMUX_NUM_PADS                                 SOC_XWR6843AOP_PINU4_PADBW


#ifdef __cplusplus
}
#endif

#endif /* ti_drivers_PINMUX_xwr68xx__include */


